From 5c57c740c1a3a7acbb384dcf2557fd129fa7328c Mon Sep 17 00:00:00 2001
From: lpw <812862340@qq.com>
Date: Thu, 16 Jul 2026 14:30:49 +0800
Subject: [PATCH] 提交版本 4.13.1
---
WAAdmobImpl/GoogleMobileAds.xcframework/ios-arm64_x86_64-simulator/GoogleMobileAds.framework/Headers/GADAppOpenAd.h | 35 ++++++++++++++++++++++++++++-------
1 files changed, 28 insertions(+), 7 deletions(-)
diff --git a/WAAdmobImpl/GoogleMobileAds.xcframework/ios-arm64_x86_64-simulator/GoogleMobileAds.framework/Headers/GADAppOpenAd.h b/WAAdmobImpl/GoogleMobileAds.xcframework/ios-arm64_x86_64-simulator/GoogleMobileAds.framework/Headers/GADAppOpenAd.h
index 8f80de4..27446f4 100644
--- a/WAAdmobImpl/GoogleMobileAds.xcframework/ios-arm64_x86_64-simulator/GoogleMobileAds.framework/Headers/GADAppOpenAd.h
+++ b/WAAdmobImpl/GoogleMobileAds.xcframework/ios-arm64_x86_64-simulator/GoogleMobileAds.framework/Headers/GADAppOpenAd.h
@@ -22,6 +22,7 @@
NSError *_Nullable error);
/// An app open ad. Used to monetize app load screens.
+NS_SWIFT_NAME(AppOpenAd)
@interface GADAppOpenAd : NSObject <GADFullScreenPresentingAd>
/// Loads an app open ad.
@@ -31,7 +32,16 @@
/// @param completionHandler A handler to execute when the load operation finishes or times out.
+ (void)loadWithAdUnitID:(nonnull NSString *)adUnitID
request:(nullable GADRequest *)request
- completionHandler:(nonnull GADAppOpenAdLoadCompletionHandler)completionHandler;
+ completionHandler:(nonnull GADAppOpenAdLoadCompletionHandler)completionHandler
+ NS_SWIFT_NAME(load(with:request:completionHandler:))NS_SWIFT_SENDING;
+
+/// Loads an app open ad.
+///
+/// @param adResponseString A server-to-server ad response string.
+/// @param completionHandler A handler to execute when the load operation finishes or times out.
++ (void)loadWithAdResponseString:(nonnull NSString *)adResponseString
+ completionHandler:(nonnull GADAppOpenAdLoadCompletionHandler)completionHandler
+ NS_SWIFT_NAME(load(with:completionHandler:))NS_SWIFT_SENDING;
/// Optional delegate object that receives notifications about presentation and dismissal of full
/// screen content from this ad. Full screen content covers your application's content. The delegate
@@ -48,16 +58,27 @@
/// Called when the ad is estimated to have earned money. Available for allowlisted accounts only.
@property(nonatomic, nullable, copy) GADPaidEventHandler paidEventHandler;
-/// Returns whether the app open ad can be presented from the provided root view controller. Sets
-/// the error out parameter if the app open ad can't be presented. Must be called on the main
-/// thread. If rootViewController is nil, uses the top view controller of the application's main
-/// window.
+/// An identifier for a placement in reporting. This property must be set prior to presenting the
+/// ad.
+@property(nonatomic, readwrite) int64_t placementID;
+
+/// Indicates whether the app open ad can be presented from the provided root view controller. Must
+/// be called on the main thread.
+///
+/// - Parameters:
+/// - rootViewController: The root view controller to present the ad from. If `rootViewController`
+/// is `nil`, uses the top view controller of the application's main window.
+/// - error: Sets the error out parameter if the ad can't be presented.
+/// - Returns: `YES` if the app open ad can be presented from the provided root view controller,
+/// `NO` otherwise.
- (BOOL)canPresentFromRootViewController:(nullable UIViewController *)rootViewController
- error:(NSError *_Nullable __autoreleasing *_Nullable)error;
+ error:(NSError *_Nullable __autoreleasing *_Nullable)error
+ NS_SWIFT_NAME(canPresent(from:)) NS_SWIFT_UI_ACTOR;
/// Presents the app open ad with the provided view controller. Must be called on the main thread.
/// If rootViewController is nil, attempts to present from the top view controller of the
/// application's main window.
-- (void)presentFromRootViewController:(nullable UIViewController *)rootViewController;
+- (void)presentFromRootViewController:(nullable UIViewController *)rootViewController
+ NS_SWIFT_NAME(present(from:)) NS_SWIFT_UI_ACTOR;
@end
--
Gitblit v1.8.0